pub struct FileObject {
pub file_data: Option<String>,
pub file_id: Option<String>,
pub filename: Option<String>,
}Available on crate feature
chat-completion-types only.Fields
file_data: Option<String>The base64 encoded file data, used when passing the file to the model as a string.
file_id: Option<String>The ID of an uploaded file to use as input.
filename: Option<String>The name of the file, used when passing the file to the model as a string.